% valueStore(i,:) = {t,V,X,S};
% with t: vector of time points [h]
% V: Volume of reactor [L]
% X: Biomass [g/L]
% S = [S_glucose, S_delftibactin] [mmol/L]

% set global parameters, aka prices!

% glucose price [$/mmol glucose] 
PglcDollar = 0.13*10^(-3);
% USD-EUR Exchange Rate of 0.7253 as of 09:06:59, 28/10/2013
% http://www.bloomberg.com/quote/EURUSD:CUR
dollarToEuro = 0.7253;
% glucose price [Euros/mmol glucose]
Pglc = PglcDollar * dollarToEuro;

% Technician pay per month [Euros]
Ptechnician = 2000;
% Power consumption of reactor [kWh]
reactorPower = 2.5;
% price per Kwh in Euros, 2013 germany data from eurostat for industrial consumers incl.taxes
% http://appsso.eurostat.ec.europa.eu/nui/submitViewTableAction.do
pricePerKWh = 0.1879;
% Reactor operating costs [Euros/hour]
Preactor = Ptechnician/24/30 + reactorPower*pricePerKWh;

% H2O2 (35%) price [Euros/Liter solution]
priceH2O2Solution = 6.54 ;
% v/v of above solution that has to be added to medium
vvH2O2 = 1/500;
% H2O2 solution price for 1 L medium [Euros/Liter growth medium]
pH2O2 = vvH2O2 * priceH2O2Solution;

% hours required after reactor has finished operating
% and next batch can start
Tcleanup = 3;

% actually start calculating costs..
costs = [];
%newBiomass = biomassValues;
costs = nan(size(valueStore,1),1);
for i=1:size(valueStore,1)
	if isempty(valueStore{i,1})
		costs(i) = 1000; %quick hack to quickly filter out those values later
		continue
	end

	% calculate Tf [h]
	% first time point at which delftibactin concentration has not increased
	TfIndex = find(~ diff(valueStore{i,4}(:,2)),1)
	Tf = valueStore{i,1}(TfIndex)

	% calculate nGlc [mmol] which was used up
	Vo = valueStore{i,2}(1)
	Vf = valueStore{i,2}(end)
	cGlcFeed = 1000
	cGlcStart = valueStore{i,4}(1,1)

	nGlc = cGlcStart*Vo + cGlcFeed*(Vf-Vo)

	% calculate nDelftibactin [mmol]
	cDelftibactinFinal = valueStore{i,4}(end,2)
	nDelftibactin = cDelftibactinFinal*Vf

    % final price per mmol Delftibactin
    Pdelfti = (nGlc*Pglc + (Tf+Tcleanup )*Preactor + Vf*pH2O2)/nDelftibactin
    if ~isempty(Pdelfti)
    	costs(i) = Pdelfti;
    end
   
end
%scatter(biomassValues(20:120), costs(20:120))
