%% DESCRIPTION

%  Configure: COBRA Linear Programming Solver
%clear all
initCobraToolbox
makeDelftiStrain
%% Perform Dynamic Scanning in FedBatch Reactor
  numPntsEnvelope = 150;      % number of points used to plot the production Envelope
  numPnts = 150;               % number of points to perform full analysis on

% Creating the Envelope
[biomassValuesFull,targetValuesFull] = productionEnvelope(model,[],'r--',targetRxn,biomassRxn,[],numPntsEnvelope);
hold on;
[biomassValues,targetValues] = productionEnvelope(model,[],'bx',targetRxn,biomassRxn,[],numPnts);

targetValues_lb = targetValues(:,1); %lowerbound of the product envelope
targetValues_ub = targetValues(:,2); %upperbound of the target product envelope
hyp_yield = targetValues(:,2)/10.5; %20 mmol/glc/sec
biomassValues(1)=[];
targetValues_ub(1) = [];
targetValues_lb(1) = [];
hyp_yield(1)=[];

% global variables declared to keep track of the target yield across
% simulations.
global hyp_yield;
global sim_i;


l = length(biomassValues);

valueStore = cell(l,4);
for i =1:l
    model = changeRxnBounds(model,targetRxn,targetValues_ub(i),'b');

    community.species = [model];
    community.mets = {'EX_glc(e)','delftibactin'};
    community.Xfeed= [0];                           %biomass feed concentration [g/L]
    community.Sfeed = [1000 0];     %      substrate feed concentration [mmol/L]

    community.Fin = 0;      
    community.Fout = 0;
        
    initV = 1;                                       %initial volume [L]
    initX = [0.01];                                     %initial biomass [g/L]
    initS = [20 0];                                   %initial metabolite [mmol/L]
    initialConditions = [initV initX initS];
    
    tspan = [0:0.1:100000];
    [t, V, X, S] = DyMMM(community, tspan, initialConditions, 'ode45n');
    valueStore(i,:) = {t,V,X,S};
    save valueStore
end


